function [] = pickPoint(src, ~)
%PICKPOINT Lets the user pick a point in the plot.
%   Selection can be aborted by using the right mouse button.

global artoaGui artoaWorkspace artoaConfig;

modeName = 'pickPoint';

%% Check for any active mode
if strcmp(artoaGui.editTimeOfArrival.currentInteractionMode, modeName)
    % pickPoint mode is active, so finish the mode
    closePickPointMode();
    return;
end

if ~islogical(artoaGui.editTimeOfArrival.currentInteractionMode)
    errordlg('Another interaction mode is currently active. Please finish it first!', 'Interaction mode error!');
    return;
end

%% Check if point is already selected
if ~artoa.controller.edit.timeOfArrival.dropSelection()
    return;
end

%% Set mode to pickPoint
openPickPointMode();

%% Initialize variable
artoaGui.editTimeOfArrival.userSelection = {};
artoaWorkspace.editTimeOfArrival.userSelection = false(length(artoaWorkspace.toaData.toa), 1);

button = src;

return

%% Helper functions

    function openPickPointMode()
        pan('off');
        zoom('off');
        brush('off');
        
        artoaGui.editTimeOfArrival.axesScatterTimeOfArrival.ButtonDownFcn = @onPick;
        artoaGui.editTimeOfArrival.scatterTimeOfArrival.ButtonDownFcn = @onDirectPick;
        artoaGui.editTimeOfArrival.currentInteractionMode = modeName;
        artoaGui.figures.editTimeOfArrival.Color = [.6 .6 .6];
        src.String = 'Finish';
        drawnow;
    end

    function closePickPointMode()
        artoaGui.editTimeOfArrival.axesScatterTimeOfArrival.ButtonDownFcn = '';
        artoaGui.editTimeOfArrival.scatterTimeOfArrival.ButtonDownFcn = '';
        artoaGui.editTimeOfArrival.currentInteractionMode = false;
        artoaGui.figures.editTimeOfArrival.Color = [.94 .94 .94];
        src.String = 'Point(s)';
        drawnow;
    end

    function onDirectPick(~, event)
        [x_closest, y_closest, index] = findClosestMatch(event.IntersectionPoint(1), event.IntersectionPoint(2));
        if islogical(index)
            return;
        end
        hold on;
        artoaGui.editTimeOfArrival.userSelection{end + 1} = scatter( ...
            x_closest, y_closest, ...
            artoaConfig.defaults.pickPointMarkerSize, [0 0 0] ...
            );
        hold off;
        artoaWorkspace.editTimeOfArrival.userSelection(index) = true;
        button.String = ['Finish ' num2str(sum(artoaWorkspace.editTimeOfArrival.userSelection)) ' selected'];
    end

    function onPick(~, event)
        [x_closest, y_closest, index] = findClosestMatch( ...
            event.IntersectionPoint(1), event.IntersectionPoint(2) ...
            );
        if islogical(index)
            return;
        end
        hold on;
        artoaGui.editTimeOfArrival.userSelection{end + 1} = scatter(x_closest, y_closest, artoaConfig.defaults.pickPointMarkerSize, [0 0 0]);
        hold off;
        artoaWorkspace.editTimeOfArrival.userSelection(index) = true;
        button.String = ['Finish ' num2str(sum(artoaWorkspace.editTimeOfArrival.userSelection)) ' selected'];
    end

    function [x_closest, y_closest, index] = findClosestMatch(dx, dy, ignoreDeleted)
        if nargin == 2
            ignoreDeleted = false;
        end
        % find closest match
        % calculate distance
        distance = sqrt((artoaWorkspace.toaData.toaDate - dx).^2 + (artoaWorkspace.toaData.toa - dy).^2);
        [~, index] = min(distance);
        x_closest = artoaWorkspace.toaData.toaDate(index);
        y_closest = artoaWorkspace.toaData.toa(index);
        if ~ignoreDeleted & (artoaWorkspace.toaData.status(index) ~= 2)
            return;
        end
        % reset output because the point is deleted
        x_closest = false;
        y_closest = false;
        index = false;
    end

end

