function [ boolean ] = has_best_guess( p_profile )
%HAS_BEST_GUESS Checks if profile has best guess coordinates as well as time.
%
%   Returns: True if best guess information is available.
%            Displays a warning if parameters are wrong, but returns false!
%
%   Parameters:
%   p_profile:          The nemo profile that is being checked.

%% Initializing return variables
boolean = false;

%% Parameter check

if (~isstruct(p_profile))
    disp([mfilename ': Wrong parameter. Please check your input. Returning false!']);
end

%% Check if GPS section is available
if (~isfield(p_profile, 'SECOND_ORDER_INFORMATION') ...
        || ~isfield(p_profile.SECOND_ORDER_INFORMATION, 'best_guess_position_lat') ...
        || ~isfield(p_profile.SECOND_ORDER_INFORMATION, 'best_guess_position_lon') ...
        || ~isfield(p_profile.SECOND_ORDER_INFORMATION, 'best_guess_position_src'))
        || ~isfield(p_profile.SECOND_ORDER_INFORMATION, 'best_guess_datevec'))
        || ~isfield(p_profile.SECOND_ORDER_INFORMATION, 'best_guess_datevec_src'))
    boolean = false;
    return
else
    % check if the values are available
    boolean = ~isnan(p_profile.SECOND_ORDER_INFORMATION.best_guess_position_lat);
end

return;

end

